@@ -79,7 +79,7 @@ namespace Rcpp{
             if (Rf_isNull(rn))
                 return 0;
             if (TYPEOF(rn) == INTSXP && LENGTH(rn) == 2 && INTEGER(rn)[0] == NA_INTEGER)
-                return abs(INTEGER(rn)[1]);
+                return std::abs(INTEGER(rn)[1]);
             return LENGTH(rn);
         }
 
@@ -101,7 +101,7 @@ namespace Rcpp{
             if( ::Rf_inherits( x, "data.frame" )){
                 Parent::set__( x ) ;
             } else{
-                SEXP y = internal::convert_using_rfunction( x, "as.data.frame" ) ;
+                Shield<SEXP> y(internal::convert_using_rfunction( x, "as.data.frame" )) ;
                 Parent::set__( y ) ;
             }
         }
@@ -130,7 +130,7 @@ namespace Rcpp{
             obj.erase(strings_as_factors_index) ;
             names.erase(strings_as_factors_index) ;
             obj.attr( "names") = names ;
-            Shield<SEXP> call( Rf_lang3(as_df_symb, obj, wrap( strings_as_factors ) ) ) ;
+            Shield<SEXP> call( Rf_lang3(as_df_symb, obj, Rf_ScalarLogical(strings_as_factors) ) ) ;
             SET_TAG( CDDR(call),  strings_as_factors_symb ) ;
             Shield<SEXP> res(Rcpp_fast_eval(call, R_GlobalEnv));
             DataFrame_Impl out( res ) ;
