@@ -22,6 +22,25 @@
 #ifndef Rcpp_macros_macros_h
 #define Rcpp_macros_macros_h
 
+#include <string>
+
+namespace Rcpp {
+namespace internal {
+namespace debug {
+
+inline std::string short_file_name(const char* file)
+{
+    std::string f(file);
+    size_t index = f.find("/include/");
+    if (index != std::string::npos)
+        f = f.substr(index + 9);
+    return f;
+}
+
+} // namespace debug
+} // namespace internal
+} // namespace Rcpp
+
 #define RCPP_DECORATE(__FUN__) __FUN__##__rcpp__wrapper__
 #define RCPP_GET_NAMES(x) Rf_getAttrib(x, R_NamesSymbol)
 #define RCPP_GET_CLASS(x) Rf_getAttrib(x, R_ClassSymbol)
@@ -98,7 +117,9 @@
   catch (...) {                                                                \
     return string_to_try_error("c++ exception (unknown reason)");              \
   }                                                                            \
-  return R_NilValue;
+  UNPROTECT(nprot);                                                            \
+  return R_NilValue;                                                           \
+  (void) stop_sym;   /* never reached but suppresses warning */
 #endif
 
 #define Rcpp_error(MESSAGE) throw Rcpp::exception(MESSAGE, __FILE__, __LINE__)
